@@ -4,7 +4,7 @@
 ## Copyright (C) 2015 Pavol Bauer
 ## Copyright (C) 2017 -- 2019 Robin Eriksson
 ## Copyright (C) 2015 -- 2019 Stefan Engblom
-## Copyright (C) 2015 -- 2020 Stefan Widgren
+## Copyright (C) 2015 -- 2022 Stefan Widgren
 ##
 ## SimInf is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -211,6 +211,6 @@ events_SEIR <- function() {
 ##' summary(result)
 u0_SEIR <- function() {
     u0 <- u0_SIR()
-    u0$E <- 0
+    u0$E <- 0L
     u0[, c("S", "E", "I", "R")]
 }
