@@ -223,3 +223,29 @@ setMethod(
               model@tspan, n_nodes(model), index, "node")
     }
 )
+
+##' Extract filtered trajectory from running a particle filter
+##'
+##' @param model the \code{SimInf_pfilter} object to extract the
+##'     result from.
+##' @template compartments-param
+##' @template index-param
+##' @param format the default (\code{format = "data.frame"}) is to
+##'     generate a \code{data.frame} with one row per node and
+##'     time-step with the number of individuals in each
+##'     compartment. Using \code{format = "matrix"} returns the result
+##'     as a matrix, which is the internal format (see
+##'     \sQuote{Details} in
+##'     \code{\link{trajectory,SimInf_model-method}}).
+##' @return A \code{data.frame} if \code{format = "data.frame"}, else
+##'     a matrix.
+##' @include pfilter.R
+##' @export
+setMethod(
+    "trajectory",
+    signature(model = "SimInf_pfilter"),
+    function(model, compartments, index,
+             format = c("data.frame", "matrix")) {
+        trajectory(model@model, compartments, index, format)
+    }
+)
