@@ -4,7 +4,7 @@
 ## Copyright (C) 2015 Pavol Bauer
 ## Copyright (C) 2017 -- 2019 Robin Eriksson
 ## Copyright (C) 2015 -- 2019 Stefan Engblom
-## Copyright (C) 2015 -- 2020 Stefan Widgren
+## Copyright (C) 2015 -- 2021 Stefan Widgren
 ##
 ## SimInf is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ library(tools)
 source("util/check.R")
 
 ## Specify the number of threads to use.
-set_num_threads(1)
+max_threads <- set_num_threads(1)
 
 ## For debugging
 sessionInfo()
@@ -72,7 +72,7 @@ stopifnot(identical(dim(p), c(1L, 1001L)))
 p <- prevalence(result, I ~ S + I, level = 3, format = "matrix")
 stopifnot(identical(dim(p), c(1L, 1001L)))
 
-if (SimInf:::have_openmp()) {
+if (SimInf:::have_openmp() && max_threads > 1) {
     stopifnot(identical(set_num_threads(2), 1L))
     result <- run(model)
     set_num_threads(1)
@@ -133,7 +133,7 @@ stopifnot(identical(dim(p), c(1L, 1001L)))
 p <- prevalence(result, I ~ S + I, level = 3, format = "matrix")
 stopifnot(identical(dim(p), c(1L, 1001L)))
 
-if (SimInf:::have_openmp()) {
+if (SimInf:::have_openmp() && max_threads > 1) {
     set_num_threads(2)
     result <- run(model)
     set_num_threads(1)
@@ -200,7 +200,7 @@ stopifnot(identical(dim(p), c(1L, 1000L)))
 p <- prevalence(result, I_1 + I_2 + I_3 ~ ., level = 3, format = "matrix")
 stopifnot(identical(dim(p), c(10L, 1000L)))
 
-if (SimInf:::have_openmp()) {
+if (SimInf:::have_openmp() && max_threads > 1) {
     set_num_threads(2)
     result <- run(model)
     set_num_threads(1)
@@ -270,7 +270,7 @@ stopifnot(identical(dim(p), c(1L, 1000L)))
 p <- prevalence(result, I_1 + I_2 + I_3 ~ ., level = 3, format = "matrix")
 stopifnot(identical(dim(p), c(10L, 1000L)))
 
-if (SimInf:::have_openmp()) {
+if (SimInf:::have_openmp() && max_threads > 1) {
     set_num_threads(2)
     result <- run(model)
     set_num_threads(1)
